#pragma once

class CSerial
{
public:
	CSerial(void);
	virtual ~CSerial(void);
	// 端口句柄
	HANDLE m_hComm;
	bool m_bSerial;
	// 打开端口
	bool OpenPort(int iPort,int Baud);
	// 往端口送数
	int WriteData(unsigned char* pData, int len);
	void SetBaud(int iBaud);
	int m_iBaud;
	int ReadData(unsigned char* pData, int len);
	int m_iPort;
	bool OpenPortNone(int iPort);
	void ClosePort(void);
	int GetStatus(int iParam);
	int PrintString(int xpos, int ypos, char* str, int len);
	int CutPaper(void);
	int FeedPaper(int iMm);
};
