// WinceDll.h : WinceDll DLL 的主头文件
//

/*

#pragma once

#ifndef __AFXWIN_H__
	#error "在包含此文件之前包含“stdafx.h”以生成 PCH 文件"
#endif

#ifdef POCKETPC2003_UI_MODEL
#include "resourceppc.h"
#endif 

// CWinceDllApp
// 有关此类实现的信息，请参阅 WinceDll.cpp
//

class CWinceDllApp : public CWinApp
{
public:
	CWinceDllApp();

// 重写
public:
	virtual BOOL InitInstance();

	DECLARE_MESSAGE_MAP()
};

*/


#ifndef _WINCEDLL_H
#define _WINCEDLL_H

extern "C" _declspec(dllexport) int OpenPort(int iPort);
extern "C" _declspec(dllexport) void ClosePort();
extern "C" _declspec(dllexport) int WriteData(unsigned char *pData,int len);
extern "C" _declspec(dllexport) int ReadData(unsigned char *pData,int len);
extern "C" _declspec(dllexport) int GetStatus(int iParam);
extern "C" _declspec(dllexport) int CutPaper();
extern "C" _declspec(dllexport) int FeedPaper(int iMm);
extern "C" _declspec(dllexport) int PrintString(int xpos, int ypos, char* str, int len);

extern "C" _declspec(dllexport) int TestPrintString();


#endif